@@ -13,9 +13,6 @@
 f7Gallery <- function() { # nocov start
   if (!requireNamespace(package = "shiny"))
     message("Package 'shiny' is required to run this function")
-  if (!requireNamespace(package = "plotly"))
-    message("Package 'plotly' is required to run this function")
-
   shiny::shinyAppFile(
     system.file(
       "examples/gallery/app.R",
