@@ -1,4 +1,20 @@
+#contacts_list <- f7List(
+#  mode = "contacts",
+#  lapply(seq_along(LETTERS), function(i) {
+#    f7ListGroup(
+#      title = LETTERS[i],
+#      lapply(seq_along(LETTERS), function(j) {
+#        f7ListItem(letters[j])
+#      })
+#    )
+#  })
+#)
+#
+#contacts_list$attribs$id <- "list-index-target"
+
+
 tabLists <- f7Tab(
+  title = "Lists",
   tabName = "Lists",
   icon = f7Icon("list_dash", f7Badge("New", color = "red")),
   active = FALSE,
@@ -67,7 +83,7 @@ tabLists <- f7Tab(
             commodo augue id, pulvinar lacus.",
         media = tags$img(src = paste0("https://cdn.framework7.io/placeholder/people-160x160-", j, ".jpg")),
         right = "Right Text",
-        url = "https://www.google.com"
+        href = "https://www.google.com"
       )
     })
   ),
@@ -108,18 +124,8 @@ tabLists <- f7Tab(
     })
   )#,
   #br(),
-  #
+
   ## list index
   #f7BlockTitle(title = "f7ListIndex") %>% f7Align(side = "center"),
-  #f7ListIndex(
-  #  id = "listIndex1",
-  #  lapply(seq_along(LETTERS), function(i) {
-  #    f7ListGroup(
-  #      title = LETTERS[i],
-  #      lapply(1:3, function(j) {
-  #        f7ListIndexItem(letters[j])
-  #      })
-  #    )
-  #  })
-  #)
+  #contacts_list
 )
